package com.vr4p.admin.vr4p_simple_demo;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.view.View;
import android.view.WindowManager;

import com.vr4p.admin.lib.VREngine;

import java.io.File;

public class MainActivity extends Activity
{
    MyGLSurfaceView  mView;

    File            fExtFileDir;

    String          strExtFileDir;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        Context context = getApplicationContext();
        try
        {
            fExtFileDir=context.getExternalFilesDir(null);
            if(!fExtFileDir.exists())
                fExtFileDir.mkdirs();
            strExtFileDir = fExtFileDir.getAbsolutePath();
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }

        mView = new MyGLSurfaceView(context);
        getWindow().setFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON, WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        setContentView(mView);

        mView.setSystemUiVisibility(View.SYSTEM_UI_FLAG_LOW_PROFILE
                | View.SYSTEM_UI_FLAG_FULLSCREEN
                | View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                | View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY
                | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
                | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION);

        //==============================================================================================================
        //设置VR头盔模式，VR一体机、VR盒子，都必须设置为true；无VR盒子时用手机观看设置为false
        VREngine.CfgSetGlassMode(true); //VREngine.CfgSetGlassMode(false);

        //==============================================================================================================
        //设置FOV， 这里是弧度，所以需要转化；往往比VR头盔标注的FOV小
        //VREngine.CfgSetFovV(3.14159265f * 88.0f / 180.0f);
        //VREngine.CfgSetFovV(3.14159265f * 90.0f / 180.0f);
        //VREngine.CfgSetFovV(3.14159265f * 91.0f / 180.0f);

        VREngine.CfgSetFovV(3.14159265f * 90.7f / 180.0f);

        //VREngine.CfgSetRenderBKRed(true);
        //==============================================================================================================
        //设置畸变修正参数，   公式为： 1 + K1 * R * R + K2 * R * R * R * R     K1   K2 为参数；由于R的单位不一样，所以K1 K2的跟你们以前的设置的值可能不一样
        //VREngine.CfgSetUndistortParam(0.84f, 0.0f);
        VREngine.CfgSetUndistortParam(0.877f, 0.0f);
        //VREngine.CfgSetUndistortParam(0.88f, 0.0f);
        //VREngine.CfgSetUndistortParam(0.92f, 0.040f);
        //VREngine.CfgSetUndistortParam(0.93f, 0.045f);

        //VREngine.CfgSetUndistortParam(0.93f, 0.045f);

        //==============================================================================================================
        //缩放显示区域的大小（圆的直径），透过头盔刚好看到圆黑边为最佳，既不浪费CPU，又达到视野最大；
        //VREngine.CfgSetGlassViewPortScale(1.13f);
        VREngine.CfgSetGlassViewPortScale(1.15f);
        //VREngine.CfgSetGlassViewPortScale(0.5f);

        //==============================================================================================================
        //屏幕显示修正；0表示不旋转，1表示逆时针旋转90度，2表示顺时针旋转90度，3表示旋转180度
        VREngine.CfgSetGlassViewPortRotate(0);

        //==============================================================================================================
        //设置中间不显示区域的宽度，主要是手机上，VR盒子与手机屏幕有缝，不设置一定宽度，左眼可能透过缝看到右屏，一体机一般可以设置小一些甚至0
        VREngine.CfgSetCenterBlackWidth(6);

        //==============================================================================================================
        //设置显示区域中心点的偏移， 在水平方向主要是与瞳距匹配； 一般CfgComCenterOffsetVByPupiDis返回的就是比较合适的瞳距
        //但如果头盔的瞳距 S1 跟人的瞳距 S0 不一致，还是需要通过调整iOffsetInPixel来进行修正
        //VREngine.CfgSetCenterOffset(5, 50);

       VREngine.CfgSetCenterOffset(10, 25);


        //================================================================================================================
        //读取VRV视频文件
        String  strVRVFileName = strExtFileDir;
        strVRVFileName += "/Test.vrv";
        VREngine.PlayVRV(strVRVFileName,"",0,true,"");  //  VREngine.PlayVRV("Test","192.168.1.1",12442,true,"");
    }

    @Override
    protected void onPause()
    {
        super.onPause();
        mView.onPause();
    }

    @Override
    protected void onResume()
    {
        mView.setSystemUiVisibility(View.SYSTEM_UI_FLAG_LOW_PROFILE
                | View.SYSTEM_UI_FLAG_FULLSCREEN
                | View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                | View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY
                | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
                | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION);
        super.onResume();
        mView.onResume();
    }

    public void onWindowFocusChanged(boolean hasFocus)
    {
        mView.setSystemUiVisibility(View.SYSTEM_UI_FLAG_LOW_PROFILE
                | View.SYSTEM_UI_FLAG_FULLSCREEN
                | View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                | View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY
                | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
                | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION);
    }
}
