package com.vr4p.admin.vr4p_simple_demo;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.opengl.GLES20;
import android.opengl.GLSurfaceView;
import android.opengl.GLUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.SurfaceHolder;

import com.vr4p.admin.lib.VREngine;

import java.io.IOException;
import java.io.InputStream;

import javax.microedition.khronos.egl.EGL10;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.egl.EGLDisplay;
import javax.microedition.khronos.opengles.GL10;

import static android.opengl.EGL14.EGL_OPENGL_ES2_BIT;
import static android.opengl.EGL14.EGL_WINDOW_BIT;


public class MyGLSurfaceView extends GLSurfaceView
{
    private MyRenderer renderer;

    private class MyVR4PConfigChooser
            implements EGLConfigChooser
    {
        public EGLConfig chooseConfig(EGL10 egl, EGLDisplay display)
        {
            EGLConfig[]  mEglConfigMain = new EGLConfig[1];
            int[] num_config = new int[1];

            int attribs[] =
                {
                        EGL10.EGL_RENDERABLE_TYPE, EGL_OPENGL_ES2_BIT,
                        EGL10.EGL_SURFACE_TYPE, EGL_WINDOW_BIT,
                        EGL10.EGL_BLUE_SIZE,    8,
                        EGL10.EGL_GREEN_SIZE,   8,
                        EGL10.EGL_RED_SIZE,     8,
                        EGL10.EGL_ALPHA_SIZE,   8,
                        EGL10.EGL_DEPTH_SIZE,	0,
                        EGL10.EGL_STENCIL_SIZE,	8,
                        EGL10.EGL_SAMPLES,		0,
                        EGL10.EGL_NONE
                };

            egl.eglChooseConfig(display, attribs,mEglConfigMain, 1, num_config);
            return mEglConfigMain[0];
        }
    }

    public MyGLSurfaceView(Context context)
    {
        super(context);
        this.setEGLContextClientVersion(2);         // 必须为opengl es 2.0
        setEGLConfigChooser(new MyVR4PConfigChooser());
        renderer = new MyRenderer(context);
        setRenderer(renderer);
        setRenderMode(GLSurfaceView.RENDERMODE_CONTINUOUSLY);
        gestureDetector = new GestureDetector(context,onGestureListener);
    }

    GestureDetector gestureDetector;

    float   m_fLastAnglePos = 0.0f;

    GestureDetector.OnGestureListener onGestureListener =
            new GestureDetector.SimpleOnGestureListener()
            {
                public boolean onDown(MotionEvent e)
                {
                    m_fLastAnglePos = VREngine.GetRotateAngle();
                    return true;
                }

                @Override
                public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX,
                                        float distanceY)
                {   //无头盔模式下，允许手动滑屏；
                    if(!VREngine.CfgGetGlassMode())
                    {
                        float fChangeAngle = VREngine.ComputeYawAngle(e1.getX(),e1.getY(),e2.getX(),e2.getY());
                        VREngine.SetRotateAngle(m_fLastAnglePos + fChangeAngle);
                    }
                    return true;
                }
            };

    public boolean onTouchEvent(MotionEvent event)
    {
        return gestureDetector.onTouchEvent(event);
    }

    public void surfaceDestroyed(SurfaceHolder holder)
    {
        VREngine.ReleaseGLRes();
        super.surfaceDestroyed(holder);
    }

    private static class MyRenderer implements GLSurfaceView.Renderer
    {
        int         textureIcon;

        float []    fArrayPos;

        float[]     fCenterPos;

        float       fRotateAngle;

        Context      myctx;

        public MyRenderer(Context ctx)
        {
            myctx = ctx;
            fArrayPos = new float[]
                    {
                            0.6f, -0.4f, -5.0f,
                            0.6f,  0.4f, -5.0f,
                            1.4f, -0.4f, -5.0f,
                            1.4f,  0.4f, -5.0f
                    };

            fCenterPos = new float[]
                    {
                            -1.6f, 0.2f, -6.0f
                    };

            fRotateAngle = 0.0f;
        }

        //绘制的关键部分，保持如下的固定模式调用
        public void onDrawFrame(GL10 gl)
        {
            VREngine.PreRender();
            if(VREngine.CfgGetGlassMode())
            {
                if(VREngine.RenderScene(VREngine.g_iRenderScene_VRLeft))
                {
                    //绘制3D UI
                    // VREngine.Render3DUI(true,0.03f,fArrayPos,true,1.0f,textureIcon);
                    // VREngine.Render3DUI2(true,0.03f,fCenterPos,vFaceDir,0.8f,0.8f,fRotateAngle,true,1.0f,textureIcon);
                    //VREngine.Render3DProgressCircle(true,0.03f,fCenterPos,vFaceDir,0.8f,fRotateAngle,1.0f,textureIcon);
                }
                if(VREngine.RenderScene(VREngine.g_iRenderScene_VRRight))
                {
                    //绘制3D UI
                    // VREngine.Render3DUI(false,0.03f,fArrayPos,true,1.0f,textureIcon);
                    // VREngine.Render3DUI2(false,0.03f,fCenterPos,vFaceDir,0.8f,0.8f,fRotateAngle,true,1.0f,textureIcon);
                    // VREngine.Render3DProgressCircle(true,0.03f,fCenterPos,vFaceDir,0.8f,fRotateAngle,1.0f,textureIcon);
                }
            }
            else
            {
                if(VREngine.RenderScene(VREngine.g_iRenderScene_NoGlass))
                {
                    //绘制3D UI
                    // VREngine.Render3DUI(true,0.0f,fArrayPos,true,1.0f,textureIcon);
                    // VREngine.Render3DUI2(false,0.03f,fCenterPos,true,0.8f,0.8f,fRotateAngle,true,1.0f,textureIcon);
                }
            }
            VREngine.AftRender();

            //
            //绘制2D UI
            //VREngine.Render2DUI(100,100,128,128,0.5f,true,textureIcon);
            //
        }

        public void onSurfaceChanged(GL10 gl, int width, int height)
        {
            VREngine.ResizeMyGL(width, height); //固定方式调用；
        }

        public void onSurfaceCreated(GL10 gl, EGLConfig config)
        {
            textureIcon =initTexture(R.drawable.ab123);   //贴图需要在这里创建，可以用任意自己的函数创建贴图
            VREngine.ResetGLRes();                          //重新创建opengl资源，固定方式调用；
        }

        public int initTexture(int drawableId)
        {
            int[] textures = new int[1];
            GLES20.glGenTextures(1, textures, 0);
            int textureId=textures[0];
            GLES20.glBindTexture(GLES20.GL_TEXTURE_2D, textureId);
            GLES20.glTexParameterf(GLES20.GL_TEXTURE_2D, GLES20.GL_TEXTURE_MIN_FILTER,GLES20.GL_NEAREST);
            GLES20.glTexParameterf(GLES20.GL_TEXTURE_2D,GLES20.GL_TEXTURE_MAG_FILTER,GLES20.GL_LINEAR);
            GLES20.glTexParameterf(GLES20.GL_TEXTURE_2D, GLES20.GL_TEXTURE_WRAP_S,GLES20.GL_CLAMP_TO_EDGE);
            GLES20.glTexParameterf(GLES20.GL_TEXTURE_2D, GLES20.GL_TEXTURE_WRAP_T,GLES20.GL_CLAMP_TO_EDGE);

            //通过输入流加载图片===============begin===================
            InputStream is = myctx.getResources().openRawResource(drawableId);
            Bitmap bitmapTmp;
            try
            {
                bitmapTmp = BitmapFactory.decodeStream(is);
            }
            finally
            {
                try
                {
                    is.close();
                }
                catch(IOException e)
                {
                    e.printStackTrace();
                }
            }
            //通过输入流加载图片===============end=====================
            GLUtils.texImage2D
                    (
                            GLES20.GL_TEXTURE_2D,   //纹理类型，在OpenGL ES中必须为GLES20.GL_TEXTURE_2D
                            0, 					  //纹理的层次，0表示基本图像层，可以理解为直接贴图
                            bitmapTmp, 			  //纹理图像
                            0					  //纹理边框尺寸
                    );
            bitmapTmp.recycle();
            return textureId;
        }
    }
}
